@@ -41,6 +41,8 @@
 
 #define KICONTHEMES_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KICONTHEMES_NO_DEPRECATED) && !defined(KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KICONTHEMES_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KICONTHEMES_NO_DEPRECATED
-#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
+#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54000
 #endif
 #ifdef KICONTHEMES_NO_DEPRECATED_WARNINGS
 #  define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x57100
+#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x54000
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KICONTHEMES_DEPRECATED
-#  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -131,40 +133,8 @@
 #else
 #  define KICONTHEMES_DEPRECATED_VERSION_5_64(text)
 #endif
-
-#if KICONTHEMES_DEPRECATED_WARNINGS_SINCE >= 0x54100
-#  define KICONTHEMES_DEPRECATED_VERSION_5_65(text) KICONTHEMES_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KICONTHEMES_DEPRECATED_VERSION_5_65(text)
-#endif
-
-#if KICONTHEMES_DEPRECATED_WARNINGS_SINCE >= 0x54200
-#  define KICONTHEMES_DEPRECATED_VERSION_5_66(text) KICONTHEMES_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KICONTHEMES_DEPRECATED_VERSION_5_66(text)
-#endif
-
-#if KICONTHEMES_DEPRECATED_WARNINGS_SINCE >= 0x55200
-#  define KICONTHEMES_DEPRECATED_VERSION_5_82(text) KICONTHEMES_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KICONTHEMES_DEPRECATED_VERSION_5_82(text)
-#endif
-
-#if KICONTHEMES_DEPRECATED_WARNINGS_SINCE >= 0x56800
-#  define KICONTHEMES_DEPRECATED_VERSION_5_104(text) KICONTHEMES_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KICONTHEMES_DEPRECATED_VERSION_5_104(text)
-#endif
 #define KICONTHEMES_DEPRECATED_VERSION_4(minor, text)      KICONTHEMES_DEPRECATED_VERSION_4_##minor(text)
 #define KICONTHEMES_DEPRECATED_VERSION_5(minor, text)      KICONTHEMES_DEPRECATED_VERSION_5_##minor(text)
 #define KICONTHEMES_DEPRECATED_VERSION(major, minor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KICONTHEMES_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KICONTHEMES_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KICONTHEMES_DEPRECATED_VERSION(major, minor, text)
-#  define KICONTHEMES_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KICONTHEMES_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KICONTHEMES_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KICONTHEMES_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KICONTHEMES_EXPORT_H */
